@@ -214,6 +214,10 @@ class AnsibleDownloaderFactory(DownloaderFactory):
         options = {"session": self._session}
         if self._remote.proxy_url:
             options["proxy"] = self._remote.proxy_url
+            if self._remote.proxy_username and self._remote.proxy_password:
+                options["proxy_auth"] = BasicAuth(
+                    login=self._remote.proxy_username, password=self._remote.proxy_password
+                )
 
         if not self._remote.token and self._remote.username and self._remote.password:
             options["auth"] = BasicAuth(login=self._remote.username, password=self._remote.password)
