@@ -40,6 +40,7 @@ from pulp_ansible.app.models import (
     AnsibleDistribution,
     Collection,
     CollectionVersion,
+    CollectionVersionSignature,
     CollectionImport,
 )
 from pulp_ansible.app.serializers import (
@@ -88,6 +89,9 @@ class AnsibleDistributionMixin:
         context = super().get_serializer_context()
         if "path" in self.kwargs:
             context["path"] = self.kwargs["path"]
+
+        distro_content = self._distro_content
+        context["sigs"] = CollectionVersionSignature.objects.filter(pk__in=distro_content)
         return context
 
 
