@@ -6,13 +6,10 @@ the case.
 """
 from pulp_smash import api, cli, config
 from pulp_smash.utils import uuid4
-from pulp_smash.pulp3.bindings import monitor_task
+from pulp_smash.pulp3.bindings import delete_orphans, monitor_task
 
 
-from pulp_smash.pulp3.utils import (
-    delete_orphans,
-    gen_repo,
-)
+from pulp_smash.pulp3.utils import gen_repo
 
 from pulp_ansible.tests.functional.utils import gen_ansible_remote, TestCaseUsingBindings
 
@@ -49,7 +46,7 @@ class BaseExport(TestCaseUsingBindings):
         """
         body = gen_ansible_remote(
             url="https://galaxy.ansible.com",
-            requirements_file="collections:\n  - robertdebock.ansible_development_environment",
+            requirements_file="collections:\n  - testing.k8s_demo_collection",
         )
         remote_a = cls.remote_collection_api.create(body)
         remote_b = cls.remote_role_api.create(gen_ansible_remote())
@@ -70,6 +67,9 @@ class BaseExport(TestCaseUsingBindings):
         cls.export_content_count["collection_version"] = repo_ver_a.content_summary.added[
             "ansible.collection_version"
         ]["count"]
+        cls.export_content_count["collection_deprecation"] = repo_ver_a.content_summary.added[
+            "ansible.collection_deprecation"
+        ]["count"]
         cls.export_content_count["role"] = repo_ver_b.content_summary.added["ansible.role"]["count"]
 
     @classmethod
@@ -94,7 +94,7 @@ class BaseExport(TestCaseUsingBindings):
             cls.repo_api.delete(repo.pulp_href)
         cls.remote_collection_api.delete(cls.remotes[0].pulp_href)
         cls.remote_role_api.delete(cls.remotes[1].pulp_href)
-        delete_orphans(cls.cfg)
+        delete_orphans()
 
     def _delete_exporter(self, exporter):
         """
